@@ -1,7 +1,5 @@
 # In this init we load everything under utils in the Talos namespace
 
-from kerasplotlib import TrainingLog as live
-
 from ..model.normalizers import lr_normalizer
 from ..model.hidden_layers import hidden_layers
 from ..model.early_stopper import early_stopper
@@ -10,11 +8,9 @@ from . import gpu_utils
 import talos.metrics.keras_metrics as metrics
 from .sequence_generator import SequenceGenerator
 from .rescale_meanzero import rescale_meanzero
-from .experiment_log_callback import ExperimentLogCallback
 from .torch_history import TorchHistory
 from wrangle import array_split as val_split
-from .power_draw_callback import PowerDrawCallback
 from .power_draw_append import power_draw_append
 from .recover_best_model import recover_best_model
 
-del experiment_log_callback, sequence_generator
+del sequence_generator
